@@ -1,15 +1,13 @@
 package Siebel::AssertOS;
-
-use 5.010;
+use warnings;
+use strict;
 use Siebel::AssertOS::Linux::Distribution qw(distribution_name);
-use feature 'switch';
 
-our $VERSION = 0.05;
+our $VERSION = "0.07";
 
 sub import {
 
     shift;
-
     die_if_os_isnt();
 }
 
@@ -17,13 +15,14 @@ sub die_if_os_isnt {
 
     my $os = shift || $^O;
 
-    os_is($os) ? 1 : die_unsupported();
+    os_is($os) ? 1 : die_unsupported($os);
 
 }
 
 sub die_unsupported {
 
-    die 'OS unsupported';
+    my $os = shift;
+    die "The operation system $os is not supported";
 
 }
 
@@ -31,33 +30,39 @@ sub os_is {
 
     my $os = shift;
 
-    given ($os) {
+    if ( $os eq 'linux' ) {
 
-        when ('linux') {
+        # supported Linux distribuitions
+        my %distros =
+          ( redhat => 1, suse => 1, 'oracle enterprise linux' => 1 );
 
-            # supported Linux distribuitions
-            my %distros =
-              ( redhat => 1, suse => 1, 'oracle enterprise linux' => 1 );
+        my $distro = distribution_name();
 
-            my $distro = distribution_name();
+        if ( exists( $distros{$distro} ) ) {
 
-            if ( exists( $distros{ $distro } ) ) {
-
-                return 1;
-
-            }
-            else {
-
-                return 0;
-
-            }
+            return 1;
 
         }
-        when ('MSWin32') { return 1 }
-        when ('aix')     { return 1 }
-        when ('solaris') { return 1 }
-        when ('hpux')    { return 1 }
-        default          { return 0 }
+        else {
+
+            warn "The Linux distribution '$distro' is not supported";
+            return 0;
+
+        }
+
+    }
+
+    return 1 if ( $os eq 'MSWin32' );
+    return 1 if ( $os eq 'aix' );
+    return 1 if ( $os eq 'solaris' );
+    if ( $os eq 'hpux' ) {
+
+        return 1;
+
+    }
+    else {
+
+        return 0;
 
     }
 
@@ -113,10 +118,6 @@ Expects a string as parameter, being the string the OS name.
 
 Returns true or false depending on the give value. The string is restricted by those return by $^O special variable.
 
-=head1 CAVEATS
-
-Beware that Siebel is supported by specific versions of OS. This module does not check OS version or distributions version (in the case of Linux).
-
 =head1 SEE ALSO
 
 =over
@@ -135,7 +136,11 @@ L<Linux::Distribution>
 
 =item *
 
-Project website: L<https://code.google.com/p/siebel-com/>
+L<Devel::AssertOS::OSFeatures::SupportsSiebel> does almost the same thing, but implementation is different and it doesn't care about Linux distribution.
+
+=item *
+
+Project website: L<https://github.com/glasswalk3r/siebel-gnu-tools>.
 
 =back
 
@@ -145,21 +150,22 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2015 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
-This file is part of Siebel COM project.
+This file is part of Siebel GNU Tools project.
 
-Siebel COM is free software: you can redistribute it and/or modify
+Siebel GNU Tools is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
-Siebel COM is distributed in the hope that it will be useful,
+Siebel GNU Tools is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel COM.  If not, see <http://www.gnu.org/licenses/>.
+along with Siebel GNU Tools.  If not, see <http://www.gnu.org/licenses/>.
 
 =cut
+
